@@ -1,4 +1,4 @@
-/*	$OpenBSD: funmap.c,v 1.59 2019/07/11 18:20:18 lum Exp $	*/
+/*	$OpenBSD: funmap.c,v 1.63 2021/04/22 19:50:55 lum Exp $	*/
 
 /* This file is in the public domain */
 
@@ -34,7 +34,7 @@ static struct funmap *funs;
  *  0 = a toggle, non-modifiable insert/delete, region modifier, etc
  *  1 = value can be string or number value (like: file/buf name, search string)
  *  2 = multiple type value required, see auto-execute, or global-set-key, etc
- * -1 = variable length # parameters (unused at moment)
+ * -1 = error: interactive commmand, unsuitable for interpreter
  *
  * Some functions when used interactively may ask for a 'y' or 'n' (or another
  * character) to continue, in excline, a 'y' is assumed. Functions like this
@@ -48,10 +48,10 @@ static struct funmap functnames[] = {
 	{indentmode, "auto-indent-mode", 0},
 	{backtoindent, "back-to-indentation", 0},
 	{backuptohomedir, "backup-to-home-directory", 0},
-	{backchar, "backward-char", 0},
-	{delbword, "backward-kill-word", 0},
-	{gotobop, "backward-paragraph", 0},
-	{backword, "backward-word", 0},
+	{backchar, "backward-char", 1},
+	{delbword, "backward-kill-word", 1},
+	{gotobop, "backward-paragraph", 1},
+	{backword, "backward-word", 1},
 	{gotobob, "beginning-of-buffer", 0},
 	{gotobol, "beginning-of-line", 0},
 	{showmatch, "blink-and-insert", 1},		/* startup only	*/
@@ -59,7 +59,7 @@ static struct funmap functnames[] = {
 	{NULL, "c-x 4 prefix", 0},			/* internal	*/
 	{NULL, "c-x prefix", 0},			/* internal	*/
 	{executemacro, "call-last-kbd-macro", 0},
-	{capword, "capitalize-word", 0},
+	{capword, "capitalize-word", 1},
 	{changedir, "cd", 1},
 	{clearmark, "clear-mark", 0},
 	{colnotoggle, "column-number-mode", 0},
@@ -82,9 +82,9 @@ static struct funmap functnames[] = {
 	{csprevfile, "cscope-prev-file", 0},
 	{csprevmatch, "cscope-prev-symbol", 0},
 	{redefine_key, "define-key", 3},
-	{backdel, "delete-backward-char", 0},
+	{backdel, "delete-backward-char", 1},
 	{deblank, "delete-blank-lines", 0},
-	{forwdel, "delete-char", 0},
+	{forwdel, "delete-char", 1},
 	{delwhite, "delete-horizontal-space", 0},
 	{delleadwhite, "delete-leading-space", 0},
 #ifdef	REGEX
@@ -98,8 +98,9 @@ static struct funmap functnames[] = {
 	{desckey, "describe-key-briefly", 1},
 	{diffbuffer, "diff-buffer-with-file", 0},
 	{digit_argument, "digit-argument", 1},
+	{dired_jump, "dired-jump", 1},
 	{lowerregion, "downcase-region", 0},
-	{lowerword, "downcase-word", 0},
+	{lowerword, "downcase-word", 1},
 	{showversion, "emacs-version", 0},
 	{finishmacro, "end-kbd-macro", 0},
 	{gotoeob, "end-of-buffer", 0},
@@ -116,9 +117,9 @@ static struct funmap functnames[] = {
 	{poptofile, "find-file-other-window", 1},
 	{filevisitro, "find-file-read-only", 1},
 	{findtag, "find-tag", 1},
-	{forwchar, "forward-char", 0},
-	{gotoeop, "forward-paragraph", 0},
-	{forwword, "forward-word", 0},
+	{forwchar, "forward-char", 1},
+	{gotoeop, "forward-paragraph", 1},
+	{forwword, "forward-word", 1},
 	{bindtokey, "global-set-key", 2},
 	{unbindtokey, "global-unset-key", 1},
 	{globalwdtoggle, "global-wd-mode", 0},
@@ -135,10 +136,10 @@ static struct funmap functnames[] = {
 	{justone, "just-one-space", 0},
 	{ctrlg, "keyboard-quit", 0},
 	{killbuffer_cmd, "kill-buffer", 1},
-	{killline, "kill-line", 0},
-	{killpara, "kill-paragraph", 0},
+	{killline, "kill-line", 1},
+	{killpara, "kill-paragraph", 1},
 	{killregion, "kill-region", 0},
-	{delfword, "kill-word", 0},
+	{delfword, "kill-word", 1},
 	{toggleleavetmp, "leave-tmpdir-backups", 0},
 	{linenotoggle, "line-number-mode", 0},
 	{listbuffers, "list-buffers", 0},
@@ -147,29 +148,29 @@ static struct funmap functnames[] = {
 	{localunbind, "local-unset-key", 1},
 	{makebkfile, "make-backup-files", 0},
 	{makedir, "make-directory", 1},
-	{markpara, "mark-paragraph", 0},
+	{markpara, "mark-paragraph", 1},
 	{markbuffer, "mark-whole-buffer", 0},
 	{do_meta, "meta-key-mode", 0},	/* better name, anyone? */
 	{negative_argument, "negative-argument", 1},
-	{enewline, "newline", 0},
-	{lfindent, "newline-and-indent", 0},
-	{forwline, "next-line", 0},
+	{enewline, "newline", 1},
+	{lfindent, "newline-and-indent", 1},
+	{forwline, "next-line", 1},
 #ifdef NOTAB
 	{notabmode, "no-tab-mode", 0},
 #endif /* NOTAB */
 	{notmodified, "not-modified", 0},
-	{openline, "open-line", 0},
+	{openline, "open-line", 1},
 	{nextwind, "other-window", 0},
 	{overwrite_mode, "overwrite-mode", 0},
 	{poptag, "pop-tag-mark", 0},
 	{prefixregion, "prefix-region", 0},
-	{backline, "previous-line", 0},
+	{backline, "previous-line", 1},
 	{prevwind, "previous-window", 0},
 	{spawncli, "push-shell", 0},
 	{showcwdir, "pwd", 0},
-	{queryrepl, "query-replace", 1},
+	{queryrepl, "query-replace", -1},
 #ifdef REGEX
-	{re_queryrepl, "query-replace-regexp", 1},
+	{re_queryrepl, "query-replace-regexp", -1},
 #endif /* REGEX */
 	{quote, "quoted-insert", 1},
 #ifdef REGEX
@@ -180,17 +181,18 @@ static struct funmap functnames[] = {
 	{reposition, "recenter", 0},
 	{redraw, "redraw-display", 0},
 #ifdef REGEX
+	{re_repl, "replace-regexp", 2},
 	{replstr, "replace-string", 2},
 #endif /* REGEX */
 	{revertbuffer, "revert-buffer", 0},
-	{filesave, "save-buffer", 0},
+	{filesave, "save-buffer", 1},
 	{quit, "save-buffers-kill-emacs", 0},
 	{savebuffers, "save-some-buffers", 0},
-	{backpage, "scroll-down", 0},
-	{back1page, "scroll-one-line-down", 0},
-	{forw1page, "scroll-one-line-up", 0},
-	{pagenext, "scroll-other-window", 0},
-	{forwpage, "scroll-up", 0},
+	{backpage, "scroll-down", 1},
+	{back1page, "scroll-one-line-down", 1},
+	{forw1page, "scroll-one-line-up", 1},
+	{pagenext, "scroll-other-window", 1},
+	{forwpage, "scroll-up", 1},
 	{searchagain, "search-again", 0},
 	{backsearch, "search-backward", 0},
 	{forwsearch, "search-forward", 0},
@@ -206,8 +208,8 @@ static struct funmap functnames[] = {
 	{setmark, "set-mark-command", 0},
 	{setprefix, "set-prefix-string", 1},
 	{shellcommand, "shell-command", 1},
-	{piperegion, "shell-command-on-region", 0},
-	{shrinkwind, "shrink-window", 0},
+	{piperegion, "shell-command-on-region", 1},
+	{shrinkwind, "shrink-window", 1},
 #ifdef NOTAB
 	{space_to_tabstop, "space-to-tabstop", 0},
 #endif /* NOTAB */
@@ -231,12 +233,12 @@ static struct funmap functnames[] = {
 	{undo_dump, "undo-list", 0},
 	{universal_argument, "universal-argument", 1},
 	{upperregion, "upcase-region", 0},
-	{upperword, "upcase-word", 0},
+	{upperword, "upcase-word", 1},
 	{togglevisiblebell, "visible-bell", 0},
 	{tagsvisit, "visit-tags-table", 0},
 	{showcpos, "what-cursor-position", 0},
 	{filewrite, "write-file", 1},
-	{yank, "yank", 0},
+	{yank, "yank", 1},
 	{NULL, NULL, 0}
 };
 
